==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/outputs/RequestHeaderMatchConditionParametersResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Defines the parameters for RequestHeader match conditions
 * @property matchValues The match value for the condition of the delivery rule
 * @property negateCondition Describes if this is negate condition or not
 * @property operator Describes operator to be matched
 * @property selector Name of Header to be matched
 * @property transforms List of transforms
 * @property typeName
 */
public data class RequestHeaderMatchConditionParametersResponse(
    public val matchValues: List<String>? = null,
    public val negateCondition: Boolean? = null,
    public val `operator`: String,
    public val selector: String? = null,
    public val transforms: List<String>? = null,
    public val typeName: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.cdn.outputs.RequestHeaderMatchConditionParametersResponse):
            RequestHeaderMatchConditionParametersResponse =
            RequestHeaderMatchConditionParametersResponse(
                matchValues = javaType.matchValues().map({ args0 -> args0 }),
                negateCondition = javaType.negateCondition().map({ args0 -> args0 }).orElse(null),
                `operator` = javaType.`operator`(),
                selector = javaType.selector().map({ args0 -> args0 }).orElse(null),
                transforms = javaType.transforms().map({ args0 -> args0 }),
                typeName = javaType.typeName(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/outputs/RequestHeaderMatchConditionParametersResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Defines the parameters for RequestHeader match conditions
 * @property matchValues The match value for the condition of the delivery rule
 * @property negateCondition Describes if this is negate condition or not
 * @property operator Describes operator to be matched
 * @property selector Name of Header to be matched
 * @property transforms List of transforms
 * @property typeName
 */
public data class RequestHeaderMatchConditionParametersResponse(
    public val matchValues: List<String>? = null,
    public val negateCondition: Boolean? = null,
    public val `operator`: String,
    public val selector: String? = null,
    public val transforms: List<String>? = null,
    public val typeName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.cdn.outputs.RequestHeaderMatchConditionParametersResponse): RequestHeaderMatchConditionParametersResponse =
            RequestHeaderMatchConditionParametersResponse(
                matchValues = javaType.matchValues().map({ args0 -> args0 }),
                negateCondition = javaType.negateCondition().map({ args0 -> args0 }).orElse(null),
                `operator` = javaType.`operator`(),
                selector = javaType.selector().map({ args0 -> args0 }).orElse(null),
                transforms = javaType.transforms().map({ args0 -> args0 }),
                typeName = javaType.typeName(),
            )
    }
}
